@@ -40,6 +40,17 @@ class TestForms(unittest.TestCase):
         self.assertTrue(isinstance(button, Submit),
                         "<button> without type is a submit button")
 
+    def test_button_value_if_submitted(self):
+        form = self.callFUT()
+        submit = form['submit']
+        self.assertEqual(
+            submit.value_if_submitted(), '',
+            "submit default value is ''")
+        button = form['button']
+        self.assertEqual(
+            button.value_if_submitted(), '',
+            "submit default value is ''")
+
     def test_force_select(self):
         form = self.callFUT()
         form['select'].force_value('notavalue')
@@ -166,6 +177,7 @@ class TestInput(unittest.TestCase):
         self.assertEqual(form.submit_fields(), [('foo', 'bar')])
 
         form = res.forms['radio_input_form']
+        self.assertEqual(form['foo'].selectedIndex, 1)
         self.assertEqual(form['foo'].value, 'baz')
         self.assertEqual(form.submit_fields(), [('foo', 'baz')])
 
@@ -187,6 +199,34 @@ class TestInput(unittest.TestCase):
         self.assertEqual(form['foo'].value, 'fido')
         self.assertEqual(form.submit_fields(), [('foo', 'fido')])
 
+    def test_radio_input_order(self):
+        app = self.callFUT()
+        res = app.get('/form.html')
+        self.assertEqual(res.status_int, 200)
+        self.assertTrue(res.content_type.startswith('text/html'))
+
+        form = res.forms['complex_radio_input_form']
+        form['foo'].value = 'true'
+        self.assertEqual(form['foo'].value, 'true')
+        self.assertEqual(form['foo'].selectedIndex, 0)
+        self.assertEqual(form.submit_fields(), [
+            (u'__start__', u'item:mapping'),
+            ('foo', 'true'),
+            (u'__end__', u'item:mapping'),
+            (u'__start__', u'item:mapping'),
+            (u'__end__', u'item:mapping')])
+
+        res = app.get('/form.html')
+        form = res.forms['complex_radio_input_form']
+        self.assertEqual(form['foo'].value, 'true')
+        self.assertEqual(form['foo'].selectedIndex, 1)
+        self.assertEqual(form.submit_fields(), [
+            (u'__start__', u'item:mapping'),
+            (u'__end__', u'item:mapping'),
+            (u'__start__', u'item:mapping'),
+            ('foo', 'true'),
+            (u'__end__', u'item:mapping')])
+
     def test_input_unicode(self):
         app = self.callFUT('form_unicode_inputs.html')
         res = app.get('/form.html')
@@ -199,6 +239,7 @@ class TestInput(unittest.TestCase):
         self.assertEqual(form.submit_fields(), [('foo', u('Хармс'))])
 
         form = res.forms['radio_input_form']
+        self.assertEqual(form['foo'].selectedIndex, 1)
         self.assertEqual(form['foo'].value, u('Блок'))
         self.assertEqual(form.submit_fields(), [('foo', u('Блок'))])
 
@@ -1013,3 +1054,18 @@ class TestFileUpload(unittest.TestCase):
         )
         resp.mustcontain("<p>You selected 'filename'</p>",
                          "<p>with contents: 'content'</p>")
+
+    def test_post_upload_empty_files(self):
+        app = webtest.TestApp(SingleUploadFileApp())
+        resp = app.post(
+            '/',
+            upload_files=[('file', 'filename', b'')]
+        )
+        resp.mustcontain("<p>You selected 'filename'</p>",
+                         "<p>with contents: ''</p>")
+        resp = app.get('/')
+        form = resp.form
+        form['file-field'] = Upload('filename', b'', 'text/plain')
+        resp = form.submit()
+        resp.mustcontain("<p>You selected 'filename'</p>",
+                         "<p>with contents: ''</p>")
