@@ -11,30 +11,30 @@ class NoDefaultTest(unittest.TestCase):
 
     def test_nodefault(self):
         from webtest.utils import NoDefault
-        self.assertEquals(repr(NoDefault), '<NoDefault>')
+        self.assertEqual(repr(NoDefault), '<NoDefault>')
 
 
 class encode_paramsTest(unittest.TestCase):
 
     def test_encode_params_None(self):
-        self.assertEquals(utils.encode_params(None, None), None)
+        self.assertEqual(utils.encode_params(None, None), None)
 
     def test_encode_params_NoDefault(self):
-        self.assertEquals(utils.encode_params(utils.NoDefault, None), '')
+        self.assertEqual(utils.encode_params(utils.NoDefault, None), '')
 
     def test_encode_params_dict_or_list(self):
-        self.assertEquals(utils.encode_params({'foo': 'bar'}, None),
+        self.assertEqual(utils.encode_params({'foo': 'bar'}, None),
                           utils.encode_params([('foo', 'bar')], None))
 
     def test_encode_params_no_charset(self):
         # no content_type at all
-        self.assertEquals(utils.encode_params({'foo': 'bar'}, None), 'foo=bar')
+        self.assertEqual(utils.encode_params({'foo': 'bar'}, None), 'foo=bar')
         # content_type without "charset=xxxx"
-        self.assertEquals(utils.encode_params({'foo': 'bar'}, 'ba'), 'foo=bar')
+        self.assertEqual(utils.encode_params({'foo': 'bar'}, 'ba'), 'foo=bar')
 
     def test_encode_params_charset_utf8(self):
         # charset is using inconsistent casing on purpose, it should still work
-        self.assertEquals(utils.encode_params({'f': '€'}, ' CHARset=uTF-8; '),
+        self.assertEqual(utils.encode_params({'f': '€'}, ' CHARset=uTF-8; '),
                           'f=%E2%82%AC')
 
 
@@ -45,15 +45,15 @@ class make_patternTest(unittest.TestCase):
         return make_pattern(obj)
 
     def test_make_pattern_None(self):
-        self.assertEquals(self.call_FUT(None), None)
+        self.assertEqual(self.call_FUT(None), None)
 
     def test_make_pattern_regex(self):
         regex = re.compile(r'foobar')
-        self.assertEquals(self.call_FUT(regex), regex.search)
+        self.assertEqual(self.call_FUT(regex), regex.search)
 
     def test_make_pattern_function(self):
         func = lambda x: x
-        self.assertEquals(self.call_FUT(func), func)
+        self.assertEqual(self.call_FUT(func), func)
 
     def test_make_pattern_bytes(self):
         # if we pass a string, it will get compiled into a regex
@@ -67,13 +67,13 @@ class make_patternTest(unittest.TestCase):
 class stringifyTest(unittest.TestCase):
 
     def test_stringify_text(self):
-        self.assertEquals(utils.stringify("foo"), "foo")
+        self.assertEqual(utils.stringify("foo"), "foo")
 
     def test_stringify_binary(self):
-        self.assertEquals(utils.stringify(b"foo"), "foo")
+        self.assertEqual(utils.stringify(b"foo"), "foo")
 
     def test_stringify_other(self):
-        self.assertEquals(utils.stringify(123), "123")
+        self.assertEqual(utils.stringify(123), "123")
 
 
 class json_methodTest(unittest.TestCase):
@@ -92,20 +92,20 @@ class json_methodTest(unittest.TestCase):
     def test_json_method_request_calls(self):
         from webtest.utils import NoDefault
         # no params
-        self.assertEquals(self.mock.foo_json('url', params=NoDefault, c='c'),
+        self.assertEqual(self.mock.foo_json('url', params=NoDefault, c='c'),
                           ('FOO', 'url', {'content_type': 'application/json',
                                           'c': 'c',
                                           'params': NoDefault,
                                           'upload_files': None}))
         # params dumped to json
-        self.assertEquals(self.mock.foo_json('url', params={'a': 'b'}, c='c'),
+        self.assertEqual(self.mock.foo_json('url', params={'a': 'b'}, c='c'),
                           ('FOO', 'url', {'content_type': 'application/json',
                                           'c': 'c',
                                           'params': json.dumps({'a': 'b'}),
                                           'upload_files': None}))
 
     def test_json_method_request_respects_content_type_argument(self):
-        self.assertEquals(self.mock.foo_json('url', params={'a': 'b'}, c='c', content_type='application/vnd.api+json;charset=utf-8'),
+        self.assertEqual(self.mock.foo_json('url', params={'a': 'b'}, c='c', content_type='application/vnd.api+json;charset=utf-8'),
                           ('FOO', 'url', {'content_type': 'application/vnd.api+json;charset=utf-8',
                                           'c': 'c',
                                           'params': json.dumps({'a': 'b'}),
