@@ -74,7 +74,7 @@ class TestResponse(webob.Response):
 
     def _parse_forms(self):
         forms_ = self._forms_indexed = {}
-        form_texts = [str(f) for f in self.html('form')]
+        form_texts = [text_type(f) for f in self.html('form')]
         for i, text in enumerate(form_texts):
             form = forms.Form(self, text, self.parser_features)
             forms_[i] = form
@@ -161,6 +161,8 @@ class TestResponse(webob.Response):
             id=linkid,
             href_pattern=href,
             index=index, verbose=verbose)
+        extra_environ = extra_environ or {}
+        extra_environ.setdefault('HTTP_REFERER', str(self.request.url))
         return self.goto(str(found_attrs['uri']), extra_environ=extra_environ)
 
     def clickbutton(self, description=None, buttonid=None, href=None,
@@ -178,7 +180,8 @@ class TestResponse(webob.Response):
             id=buttonid,
             href_pattern=href,
             index=index, verbose=verbose)
-        return self.goto(str(found_attrs['uri']))
+        extra_environ = {'HTTP_REFERER': str(self.request.url)}
+        return self.goto(str(found_attrs['uri']), extra_environ=extra_environ)
 
     def _find_element(self, tag, href_attr, href_extract,
                       content, id,
@@ -356,7 +359,7 @@ class TestResponse(webob.Response):
             raise TypeError(
                 "The only keyword argument allowed is 'no'")
         for s in strings:
-            if not s in self:
+            if s not in self:
                 print_stderr("Actual response (no %r):" % s)
                 print_stderr(str(self))
                 raise IndexError(
@@ -413,7 +416,7 @@ class TestResponse(webob.Response):
     def html(self):
         """
         Returns the response as a `BeautifulSoup
-        <http://www.crummy.com/software/BeautifulSoup/documentation.html>`_
+        <https://www.crummy.com/software/BeautifulSoup/bs3/documentation.html>`_
         object.
 
         Only works with HTML responses; other content-types raise
@@ -429,9 +432,8 @@ class TestResponse(webob.Response):
     @property
     def xml(self):
         """
-        Returns the response as an `ElementTree
-        <http://python.org/doc/current/lib/module-xml.etree.ElementTree.html>`_
-        object.
+        Returns the response as an :mod:`ElementTree
+        <python:xml.etree.ElementTree>` object.
 
         Only works with XML responses; other content-types raise
         AttributeError
@@ -458,9 +460,8 @@ class TestResponse(webob.Response):
     @property
     def lxml(self):
         """
-        Returns the response as an `lxml object
-        <http://codespeak.net/lxml/>`_.  You must have lxml installed
-        to use this.
+        Returns the response as an `lxml object <https://lxml.de/>`_.
+        You must have lxml installed to use this.
 
         If this is an HTML response and you have lxml 2.x installed,
         then an ``lxml.html.HTML`` object will be returned; if you
@@ -481,7 +482,7 @@ class TestResponse(webob.Response):
             from lxml.html import fromstring
         except ImportError:  # pragma: no cover
             fromstring = etree.HTML
-        ## FIXME: would be nice to set xml:base, in some fashion
+        # FIXME: would be nice to set xml:base, in some fashion
         if self.content_type == 'text/html':
             return fromstring(self.testbody, base_url=self.request.url)
         else:
@@ -490,22 +491,20 @@ class TestResponse(webob.Response):
     @property
     def json(self):
         """
-        Return the response as a JSON response.  You must have `simplejson
-        <http://goo.gl/B9g6s>`_ installed to use this, or be using a Python
-        version with the json module.
-
+        Return the response as a JSON response.
         The content type must be one of json type to use this.
         """
         if not self.content_type.endswith(('+json', '/json')):
             raise AttributeError(
                 "Not a JSON response body (content-type: %s)"
                 % self.content_type)
-        return loads(self.testbody)
+        return self.json_body
 
     @property
     def pyquery(self):
         """
-        Returns the response as a `PyQuery <http://pyquery.org/>`_ object.
+        Returns the response as a `PyQuery
+        <https://pypi.org/project/pyquery/>`_ object.
 
         Only works with HTML and XML responses; other content-types raise
         AttributeError.
